<?php

		add_action( 'after_setup_theme', 'benten_theme_setup' );
		function benten_theme_setup() {
			/* Add filters, actions, and theme-supported features. */
			//THEME SUPORT FUNCTION
			//add thumbnail
			add_theme_support( 'post-thumbnails' );
			//custom background
			add_theme_support( 'custom-background' );
			add_theme_support( 'title-tag' );

			//automatic feed
			add_theme_support( 'automatic-feed-links' );
			//add menu homepage,portfolio and blog
			add_action( 'init', 'benten_register_menu' );
			add_action( 'init', 'benten_register_menu_blog' );
			// Retrieve the directory for the localization files
			$lang_dir = ( get_template_directory() . '/lang');
			 
			// Set the theme's text domain using the unique identifier from above
			load_theme_textdomain('benten', $lang_dir);
			
			//width content
			if ( ! isset( $content_width ) )$content_width = 1170;
			
			//theme styles
			//THEME SCRIPT AND STYLES
			//theme default script and styles
			add_action('wp_enqueue_scripts', 'benten_theme_scripts');
			add_action('wp_enqueue_scripts', 'benten_theme_styles');
			//parallax setting
			add_action('wp_enqueue_scripts', 'benten_parallax_bg');
			//color_schecmes script
			add_action( 'wp_enqueue_scripts', 'benten_color_scheme' );
			//register sidebar
			add_action( 'widgets_init', 'benten_sidebar' );
			
			
			
			
			
			//CUSTOM FILTER
			//wp title
			add_filter( 'wp_title', 'benten_wp_title', 10, 2 );
			//custom search setting
			add_filter( 'get_search_form', 'benten_search_form' );
			//custom excerpt
			add_filter( 'excerpt_length', 'benten_excerpt_length', 10 );
			//remove [..] in excerpt
			add_filter('get_the_excerpt', 'benten_trim_excerpt');
			//custom comment styles
			add_filter('comment_form_default_fields','benten_modify_comment_form_fields');
			//tag cloud filter
			add_filter('wp_generate_tag_cloud', 'benten_tag_cloud',10,1);
			//preloader script and styles
			add_action( 'wp_enqueue_scripts', 'benten_preloader_set' );
			add_action( 'wp_enqueue_scripts', 'benten_preloader' );
			//script for homepage setting 
			add_action('wp_enqueue_scripts','benten_homepage_script' );
			
			
			//wp title tag back compat
			if ( ! function_exists( '_wp_render_title_tag' ) ) {
				function benten_render_title() {
			?>
			<title><?php wp_title( '-', true, 'right' ); ?></title>
			<?php
				}
				add_action( 'wp_head', 'benten_render_title' );
			}
	
	}
	
	//wp title 
	function benten_wp_title( $title, $sep ) {
		global $paged, $page;
		if ( is_feed() ) {
		return $title;
		} // end if
		// Add the site name.
		$title .= get_bloginfo( 'name' );
		// Add the site description for the home/front page.
		$site_description = get_bloginfo( 'description', 'display' );
		if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title = "$title $sep $site_description";
		} // end if
		// Add a page number if necessary.
		if ( $paged >= 2 || $page >= 2 ) {
		$title = sprintf( esc_html__( 'Page %s', 'benten' ), max( $paged, $page ) ) . " $sep $title";
		} // end if
		return $title;
	}
	//tag cloud filter
	function benten_tag_cloud($string){
	   return preg_replace("/style='font-size:.+pt;'/", '', $string);
	}
	//add menu for homepage
	function benten_register_menu() {
		register_nav_menu('ridianur-homepage-menu',esc_html__( 'Menu that display only in Homepage Template','benten' ));
	}
	
	//add menu for blog
	function benten_register_menu_blog() {
		register_nav_menu('ridianur-blog-menu',esc_html__( 'Menu that display in Blog and Other Pages','benten' ));
	}
	
	//custom excerpt function
	function benten_excerpt_length( $length ) {
		return 60;
	}
	// Remove [...]
	function benten_trim_excerpt($text) {
		$text = str_replace('[', '', $text);
		$text = str_replace(']', '', $text);
		return $text;
	}
	//adding sidebar widget
	function benten_sidebar() {
		register_sidebar(array(
		'name' => esc_html__('Default Sidebar', 'benten' ),
		'id' => 'default-sidebar',
		'description' => esc_html__('Appears as the sidebar on blog and pages', 'benten' ),
		'before_widget' => '<div  id="%1$s" class="widget %2$s clearfix">','after_widget' => '</div>',
		'before_title' => '<h3 class="widgettitle">',
		'after_title' => '</h3>',));
	}
	
	
	
	/* Replacing the default WordPress search form with an HTML5 version */
	function benten_search_form( $form ) {
		$form = '<form role="search" method="get" id="searchform" action="' . home_url( '/' ) . '" > 
		<input type="search" placeholder="'.esc_html__('Search and hit enter...','benten').'" value="' . get_search_query() . '" name="s" id="s" />
		<input type="submit" id="searchsubmit" />
		</form>';
		return $form;
	}
	//custom comment form
	function benten_modify_comment_form_fields($fields){
		$req = get_option('require_name_email');
		$commenter = wp_get_current_commenter();
		$aria_req = ( $req ? " aria-required='true'" : '' ); 
		
		$fields['author'] = '<p class="comment-form-author">' . '<label for="author">' . esc_html__( 'Name', 'benten' ) . '</label> ' . 
		
		( $req ? '' : '' ) .
						
		'<input id="author" name="author" type="text" placeholder="'. esc_html__('Your Name ...','benten').'" value="' . 
						
		esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' /></p>';
						
		$fields['email'] = '<p class="comment-form-email"><label for="email">' . esc_html__( 'Email', 'benten' ) . '</label> ' .
		
		( $req ? '' : '' ) .
		
		'<input id="email" name="email" type="text" placeholder="'. esc_html__('Your Email ...','benten') .'"  value="' . 
		
		esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' /></p>';
		
		$fields['url'] = '<p class="comment-form-url"><label for="url">' . esc_html__( 'Website', 'benten' ) . '</label>' .
		
		'<input id="url" name="url" type="text" placeholder="'. esc_html__('Your Website ...','benten').'" value="' . 
		
		esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>';
		
		return $fields;
	}



	
	//THEME SCRIPTS & STYLES
	// include theme-script
	include( get_template_directory().'/inc/theme-style.php' );
	include( get_template_directory().'/inc/theme-script.php');
	//included preloader setting
	include( get_template_directory().'/inc/preloader.php');
	//include comment template
	include( get_template_directory().'/inc/comment-template.php');
	//include color schemes 
	include( get_template_directory().'/inc/color-schemes.php');
	//include parallax setting
	include( get_template_directory().'/inc/parallax.php');
	//included homepage setting
	include( get_template_directory().'/inc/homepage-setting.php');
	//included post metabox
	include( get_template_directory().'/inc/post-metaboxes.php');
	//pagination
	include( get_template_directory().'/inc/pagination.php');
	//include TGM activation
	include( get_template_directory().'/inc/plugin-install.php');
	
	
	
//adding optiontree into themes
/**
 * Optional: set 'ot_show_pages' filter to false.
 * This will hide the settings & documentation pages.
 */add_filter( 'ot_show_pages', '__return_false' );
	/**
 * Optional: set 'ot_show_new_layout' filter to false.
 * This will hide the "New Layout" section on the Theme Options page.
 */add_filter( 'ot_show_new_layout', '__return_false' );
	/**
 * Required: set 'ot_theme_mode' filter to true.
 */add_filter( 'ot_theme_mode', '__return_true' );
	/**
 * Required: include OptionTree.
 */load_template( trailingslashit( get_template_directory() ) . 'option-tree/ot-loader.php' );
	/**
 * Theme Options
 */load_template( trailingslashit( get_template_directory() ) . 'inc/theme-options.php' );
 

