<?php
/**
 * Initialize the custom theme options.
 */
add_action( 'admin_init', 'benten_custom_theme_options' );

/**
 * Build the custom settings & update OptionTree.
 */
function benten_custom_theme_options() {
  
  /* OptionTree is not loaded yet */
  if ( ! function_exists( 'ot_settings_id' ) )
    return false;
    
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( ot_settings_id(), array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
    'contextual_help' => array( 
      'sidebar'       => ''
    ),
    'sections'        => array( 
      array(
        'id'          => 'general',
        'title'       => esc_html__('General Setting', 'benten' )
      ),
      array(
        'id'          => 'slider_sectio',
        'title'       => esc_html__('Slider Setting', 'benten' )
      ),
	  array(
        'id'          => 'video_bg_setting_section',
        'title'       => esc_html__('Video Background Setting', 'benten' )
      ),
	  array(
        'id'          => 'yt_bg_setting_section',
        'title'       => esc_html__('Youtube Background Setting', 'benten' )
      ),
	  array(
        'id'          => 'sections_setting',
        'title'       => esc_html__('Sections Setting', 'benten' )
      ),
      array(
        'id'          => 'parallax_section_big_background_image',
        'title'       => esc_html__('Parallax Section/Big Background Image', 'benten' )
      ),
	  array(
        'id'          => 'footer_section',
        'title'       => esc_html__('Footer Setting', 'benten' )
      ),
	  
	  array(
        'id'          => 'custom_layout_sec',
        'title'       => esc_html__('Homepage Custom Layout', 'benten' )
      ),
	  
    ),
    'settings'        => array( 

	  array(
        'id'          => 'style_tab',
        'label'       => esc_html__('Style Setting', 'benten' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'color_general',
        'label'       => esc_html__('Color Scheme', 'benten' ),
        'desc'        => esc_html__('Pick your color scheme. Default color is #e3451e', 'benten' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'color_scheme',
        'label'       => esc_html__('Hyperlink Color', 'benten' ),
        'desc'        => esc_html__('Pick your color for hyperlink. Default color is black #aaaaaa', 'benten' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'custom_hovers',
        'label'       => esc_html__('Hyperlink color on hover state', 'benten' ),
        'desc'        => esc_html__('Pick your color for hover state in hyperlink. Default color is #e3451e', 'benten' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'heading_color',
        'label'       => esc_html__('Color on Heading', 'benten' ),
        'desc'        => esc_html__('Pick your color for heading text. Default color is black #000000', 'benten' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'general_color',
        'label'       => esc_html__('Color on General Paragraph', 'benten' ),
        'desc'        => esc_html__('Pick your color for general paragraph text. Default color is black #8d8d8d', 'benten' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

	  array(
        'id'          => 'footer_color',
        'label'       => esc_html__('Footer Background color', 'benten' ),
        'desc'        => esc_html__('Pick your background color for footer. Default color is black #000000', 'benten' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'stick_menu',
        'label'       => esc_html__('Sticky Menu Background color', 'benten' ),
        'desc'        => esc_html__('Pick your background color for sticky menu. Default color is #000000', 'benten' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'custom_css_box',
        'label'       => esc_html__('Custom Css Box', 'benten' ),
        'desc'        => esc_html__('Insert your own css/style code here.', 'benten' ),
        'std'         => '',
        'type'        => 'css',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'logo_tab',
        'label'       => esc_html__('Logo', 'benten' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'logo_img',
        'label'       => esc_html__('Logo Upload', 'benten' ),
        'desc'        => esc_html__('Upload your logo here.<br> Recommended size 185x60px', 'benten' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
      array(
        'id'          => 'favicon_logo',
        'label'       => esc_html__('Favicon Logo', 'benten' ),
        'desc'        => esc_html__('Upload your favicon here. Recommended size 30x30px', 'benten' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'touch_logo',
        'label'       => esc_html__('Touch Logo', 'benten' ),
        'desc'        => esc_html__('Upload your touch logo here. Recommended size 129x129px', 'benten' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'preload_tab',
        'label'       => esc_html__('Preloader', 'benten' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'preloader_set',
        'label'       => esc_html__('Preloader Setting', 'benten' ),
        'desc'        => esc_html__('Choose Loader setting', 'benten' ),
        'std'         => '',
        'type'        => 'select',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'choices'     => array( 
          array(
            'value'       => 'show_home',
            'label'       => esc_html__('Show in Homepage only', 'benten' ),
            'src'         => ''
          ),
          array(
            'value'       => 'show_all',
            'label'       => esc_html__('Show in All pages', 'benten' ),
            'src'         => ''
          ),
          array(
            'value'       => 'hide_in_all',
            'label'       => esc_html__('Hide in All Pages', 'benten' ),
            'src'         => ''
          )
        )
      ),
      array(
        'id'          => 'loader_logo',
        'label'       => esc_html__('Preloader Logo Image', 'benten' ),
        'desc'        => esc_html__('Insert preloader logo image here.', 'benten' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'loader_image',
        'label'       => esc_html__('Preloader Image', 'benten' ),
        'desc'        => esc_html__('Upload your preloader image here<br />
Recommended size 128x128px', 'benten' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'loader_color',
        'label'       => esc_html__('Preloader Background Color', 'benten' ),
        'desc'        => esc_html__('Choose your background color for preloader', 'benten' ),
        'std'         => '',
        'type'        => 'colorpicker',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  
      array(
        'id'          => 'slider_list',
        'label'       => esc_html__('Homepage Slider List', 'benten' ),
        'desc'        => esc_html__('Create your slider list for main/homepage slider.<br/> For homepage with video/youtube background <b>the slider images will appear on touch devices</b> (replacing the video/youtube video).', 'benten' ),
        'std'         => '',
        'type'        => 'list-item',
        'section'     => 'slider_sectio',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'settings'    => array( 
			array(
            'id'          => 'top_text',
            'label'       => esc_html__('Slider top text', 'benten' ),
            'desc'        => esc_html__('Input your slider top text here.', 'benten' ),
            'std'         => '',
            'type'        => 'text',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
		  array(
            'id'          => 'slider_icon',
            'label'       => esc_html__('Slider icon', 'benten' ),
            'desc'        => esc_html__('Input your slider icon here. <br /> You can check <a target="_blank" href="http://fontawesome.io/icons/">Here</a> for icon list. 
			eg. fa-snowflake-o', 'benten' ),
            'std'         => '',
            'type'        => 'text',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
          array(
            'id'          => 'slider_image',
            'label'       => esc_html__('Slider Image', 'benten' ),
            'desc'        => esc_html__('Upload your slider image here. You can leave it blank if you are using homepage background video template.', 'benten' ),
            'std'         => '',
            'type'        => 'upload',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
          array(
            'id'          => 'bottom_text',
            'label'       => esc_html__('Slider bottom text', 'benten' ),
            'desc'        => esc_html__('Input your slider small/bottom text here.', 'benten' ),
            'std'         => '',
            'type'        => 'textarea-simple',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
		  		  array(
            'id'          => 'slider_link',
            'label'       => esc_html__( 'Slider Link Button', 'benten' ),
            'desc'        => esc_html__( 'Input your slider button link here( leave it blank if you don\'t want it)', 'benten' ),
            'std'         => '',
            'type'        => 'text',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
		  array(
            'id'          => 'slider_link_text',
            'label'       => esc_html__( 'Slider Link Text', 'benten' ),
            'desc'        => esc_html__( 'Input your slider text link here( leave it blank if you don\'t want it)', 'benten' ),
            'std'         => '',
            'type'        => 'text',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          )
		  
        )
      ),
      array(
        'id'          => 'slider_delay',
        'label'       => esc_html__('Homepage Slider Delay', 'benten' ),
        'desc'        => esc_html__('Set your slider delay here.', 'benten' ),
        'std'         => '10000',
        'type'        => 'numeric-slider',
        'section'     => 'slider_sectio',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '1,10000,1',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	   array(
        'id'          => 'fot_text_tab',
        'label'       => esc_html__('Footer Text', 'benten' ),
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'fot_text',
        'label'       => esc_html__('Footer Text', 'benten' ),
        'desc'        => esc_html__('Input footer text here. You can use HTML tag here.', 'benten' ),
        'std'         => '',
        'type'        => 'textarea-simple',
		'rows'        => '3',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'fot_soc_tab',
        'label'       => esc_html__('Footer Social Icon', 'benten' ),
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	   array(
        'id'          => 'fb_foot',
        'label'       => esc_html__('Facebook Link', 'benten' ),
        'desc'        => esc_html__('Input facebook link here', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'gp_foot',
        'label'       => esc_html__('Google Plus Link', 'benten' ),
        'desc'        => esc_html__('Input google plus link here', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'twit_foot',
        'label'       => esc_html__('Twitter Link', 'benten' ),
        'desc'        => esc_html__('Input twitter link here', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'pint_foot',
        'label'       => esc_html__('Pinterest Link', 'benten' ),
        'desc'        => esc_html__('Input pinterest link here', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'insta_link',
        'label'       => esc_html__('Instagram Link', 'benten' ),
        'desc'        => esc_html__('Input instagram link here', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'xing_foot',
        'label'       => esc_html__('Xing Link', 'benten' ),
        'desc'        => esc_html__('Input xing link here', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'foot_as_icon',
        'label'       => esc_html__('Another Social Icon', 'benten' ),
        'desc'        => esc_html__('Create list for another social icon.', 'benten' ),
        'std'         => '',
        'type'        => 'list-item',
        'section'     => 'footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'settings'    => array( 
          array(
            'id'          => 'foot_soc_icon',
            'label'       => esc_html__('Social Icon', 'benten' ),
            'desc'        => esc_html__('Input your social icon here. <br /> You can check <a target="_blank" href="http://fontawesome.io/icons/">Here</a> for icon list. eg. fa-github', 'benten' ),
            'std'         => '',
            'type'        => 'text',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          ),
          array(
            'id'          => 'foot_as_link',
            'label'       => esc_html__('Social Icon Link', 'benten' ),
            'desc'        => esc_html__('Input social icon link here', 'benten' ),
            'std'         => '',
            'type'        => 'text',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          )
        )
      ),
	  array(
        'id'          => 'home_setting',
        'label'       => esc_html__('Home Section Background Setting', 'benten'),
        'desc'        => esc_html__('You can set the slider/video background at slider and video background settings.', 'benten'),
        'std'         => 'slider_bg_home',
        'type'        => 'select',
        'section'     => 'custom_layout_sec',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'slider_bg_home',
            'label'       => esc_html__('Slider Background', 'benten'),
            'src'         => ''
          ),
          array(
            'value'       => 'video_bg_home',
            'label'       => esc_html__('Video Background', 'benten'),
            'src'         => ''
          ),
		  array(
            'value'       => 'youtube_bg_home',
            'label'       => esc_html__('Youtube Video Background', 'benten'),
            'src'         => ''
          )
        ),
      ),
	  array(
        'id'          => 'text_block_video_section',
        'label'       => esc_html__('THE SETTING ONLY FOR VIDEO BACKGROUND IN HOMEPAGE VIDEO TEMPLATE', 'benten' ),
        'desc'        => esc_html__('You can set your video here. This is only affect on homepage with <strong> Homepage Video</strong> template', 'benten' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'video_bg_setting_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'video_link',
        'label'       => esc_html__('Video Source', 'benten' ),
        'desc'        => esc_html__('Insert your video source here (only directlink). eg. http://yoursite.com/video.mp4', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'video_bg_setting_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),


	  array(
        'id'          => 'home_setting_box',
        'label'       => 'box text home setting',
        'desc'        => esc_html__('THIS SETTING ONLY APPLIES ON PAGE WITH  "HOMEPAGE CUSTOM LAYOUT" TEMPLATE','benten'),
        'std'         => '',
        'type'        => 'textblock',
        'section'     => 'custom_layout_sec',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'custom_layout',
        'label'       => esc_html__('Section List','benten'),
        'desc'        => esc_html__('Create your sections list here.<br/> Noted: <b>The title</b> on custom section will be the <b>id/anchor</b> to put in your homepage menu. <br/>
		Make sure <b>the title</b> doesn\'t have <b>space/white area</b> or <b>any special character</b>.','benten'),
        'std'         => '',
        'type'        => 'list-item',
        'section'     => 'custom_layout_sec',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'settings'    => array( 
			array(
            'id'          => 'section_type',
            'label'       => esc_html__('Select Section','benten'),
            'desc'        => esc_html__('Select the section that you want to add in homepage','benten'),
            'std'         => '',
            'type'        => 'select',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'choices'     => array( 
              array(
                'value'       => 'about_content',
                'label'       => esc_html__('About & Team Section', 'benten'),
                'src'         => ''
              ),
			  array(
                'value'       => 'portfolio_content',
                'label'       => esc_html__('Works Section', 'benten'),
                'src'         => ''
              ),
			  array(
                'value'       => 'services_content',
                'label'       => esc_html__('Services Section', 'benten'),
                'src'         => ''
              ),
			  array(
                'value'       => 'contact_content',
                'label'       => esc_html__('Contact Section', 'benten'),
                'src'         => ''
              ),
			  array(
                'value'       => 'para2_content',
                'label'       => esc_html__('Client Section', 'benten'),
                'src'         => ''
              ),
			  array(
                'value'       => 'custom_content',
                'label'       => esc_html__('Custom Section', 'benten'),
                'src'         => ''
              ),
            ),
          ),
			array(
				'id'          => 'custom_section',
				'label'       => esc_html__('Custom Section', 'benten' ),
				'desc'        => esc_html__('Choose your custom section post here.', 'benten' ),
				'std'         => '',
				'type'        => 'custom-post-type-select',
				'section'     => 'custom_layout_sec',
				'rows'        => '',
				'post_type'   => 'custom-section',
				'taxonomy'    => '',
				'min_max_step'=> '',
				'class'       => '',
				'condition'   => 'section_type:is(custom_content)',
				'operator'    => 'and'
			),	
        )
      ),
	  array(
        'id'          => 'section_block_title',
        'label'       => esc_html__('SECTION SETTINGS', 'benten' ),
        'desc'        => esc_html__('You can set up each section in homepage here.', 'benten' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  
	  
	  array(
        'id'          => 'about_section_tab',
        'label'       => esc_html__('About & Team', 'benten' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'about_block',
        'label'       => esc_html__('You can create about post in About Us.', 'benten' ),
        'desc'        => esc_html__('For creating about post, go to left menu About Us -> Add New About Us. <br>Only 1 about post will appear in homepage.', 'benten' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'about_small_title',
        'label'       => esc_html__('About Small Title', 'benten' ),
        'desc'        => esc_html__('Insert your small title for about section here. eg. Behind the scene', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'about_big_title',
        'label'       => esc_html__('About Big Title', 'benten' ),
        'desc'        => esc_html__('Insert your big title for about section here. eg. About Us', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'about_icon',
        'label'       => esc_html__('About Icon', 'benten' ),
        'desc'        => esc_html__('Input your about icon here. <br /> You can check <a target="_blank" href="http://fontawesome.io/icons/">Here</a> for icon list. 
			eg. fa-snowflake-o', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  array(
        'id'          => 'team_block',
        'label'       => esc_html__('You can create each team post in Team Posts.', 'benten' ),
        'desc'        => esc_html__('For creating new team post, go to left menu Team Posts -> Add New Team Post', 'benten' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  array(
        'id'          => 'team_title',
        'label'       => esc_html__('Team Section Title', 'benten' ),
        'desc'        => esc_html__('Insert your title for team section here. eg. Meet the team', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'team_toptext',
        'label'       => esc_html__('Team Section Top Text', 'benten' ),
        'desc'        => esc_html__('Insert your top text for team section here. eg. The greatest people', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  array(
        'id'          => 'services_section_tab',
        'label'       => esc_html__('Services', 'benten' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'services_block',
        'label'       => esc_html__('You can create services list in services post.', 'benten' ),
        'desc'        => esc_html__('For creating new services list, go to left menu Services Posts -> Add New Services Post', 'benten' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'services_open_text',
        'label'       => esc_html__('Services Small Title', 'benten' ),
        'desc'        => esc_html__('Insert your small title for services section here.', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '3',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'services_big_title',
        'label'       => esc_html__('Services Big Title', 'benten' ),
        'desc'        => esc_html__('Insert your big title for services section here. eg. The Services', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	 array(
        'id'          => 'services_icon',
        'label'       => esc_html__('Services Icon', 'benten' ),
        'desc'        => esc_html__('Input your services icon here.<br>You can check <a target="_blank" href="http://fontawesome.io/icons/">Here</a> 	eg. fa-snowflake-o', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '3',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	array(
        'id'          => 'services_block_two',
        'label'       => esc_html__('You can upload the background for service section in Parallax Section/Big Background Image.', 'benten' ),
        'desc'        => esc_html__('For upload the background image for services section, go to Theme options -> Parallax Section/Big Background Image->Parallax Two/Services Setting', 'benten' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

	  array(
        'id'          => 'works_portfolio_setting_tab',
        'label'       => esc_html__('Works', 'benten' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'port_block',
        'label'       => esc_html__('You can create each portfolio item in portfolio post.', 'benten' ),
        'desc'        => esc_html__('For creating new portfolio item, go to left menu Portfolio -> Add New Portfolio', 'benten' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'works_small_title',
        'label'       => esc_html__('Works Small Title', 'benten' ),
        'desc'        => esc_html__('Insert your small title for works section here. eg. All of good things', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
      array(
        'id'          => 'works_big_title',
        'label'       => esc_html__('Works Big Title', 'benten' ),
        'desc'        => esc_html__('Insert your big title for works section here. eg. Our Works', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'works_icon',
        'label'       => esc_html__('Works Icon', 'benten' ),
        'desc'        => esc_html__('IInput your works icon here. <br> You can check <a target="_blank" href="http://fontawesome.io/icons/">Here</a> for icon list. 
		eg. fa-snowflake-o', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '3',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'works_all',
        'label'       => esc_html__('Works Filter for all categories', 'benten' ),
        'desc'        => esc_html__('Insert your text for works filter for all categories. The default text is "All"', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '3',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	 	  array(
        'id'          => 'client_list_tab',
        'label'       => esc_html__('Client List', 'benten' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'client_title',
        'label'       => esc_html__('Title for client list', 'benten' ),
        'desc'        => esc_html__('Insert the title for client list here. eg. Our Recent Client', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'client_small_title',
        'label'       => esc_html__('Small Title for client list', 'benten' ),
        'desc'        => esc_html__('Insert the small title for client list here. eg. people we works', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'client_icon',
        'label'       => esc_html__('Client Icon', 'benten' ),
        'desc'        => esc_html__('Input your client icon here. <br> You can check <a target="_blank" href="http://fontawesome.io/icons/">Here</a> for icon list. eg. fa-snowflake-o', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

      array(
        'id'          => 'client_list',
        'label'       => esc_html__('Client List', 'benten' ),
        'desc'        => esc_html__('Create your client list here.', 'benten' ),
        'std'         => '',
        'type'        => 'list-item',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'settings'    => array( 
          array(
            'id'          => 'client_image',
            'label'       => esc_html__('Client Image', 'benten' ),
            'desc'        => esc_html__('Upload your client images here.', 'benten' ),
            'std'         => '',
            'type'        => 'upload',
            'rows'        => '',
            'post_type'   => '',
            'taxonomy'    => '',
            'min_max_step'=> '',
            'class'       => '',
            'condition'   => '',
            'operator'    => 'and'
          )
        )
      ),
	  array(
        'id'          => 'client_btn_text',
        'label'       => esc_html__('Client Text Button', 'benten' ),
        'desc'        => esc_html__('Insert you text button here.( leave it blank if you don\'t want it)', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'client_btn_link',
        'label'       => esc_html__('Client Button Link', 'benten' ),
        'desc'        => esc_html__('Insert your button link here.( leave it blank if you don\'t want it)', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'client_list_column',
        'label'       => esc_html__('Client List Column', 'benten' ),
        'desc'        => esc_html__('Select how many columns you want to use for client list. Default is 4 columns.', 'benten' ),
        'std'         => '',
        'type'        => 'select',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
        'choices'     => array( 
          array(
            'value'       => 'col_4',
            'label'       => esc_html__('4 Columns', 'benten' ),
            'src'         => ''
          ),
          array(
            'value'       => 'col_3',
            'label'       => esc_html__('3 Columns', 'benten' ),
            'src'         => ''
          ),
          array(
            'value'       => 'col_2',
            'label'       => esc_html__('2 Columns', 'benten' ),
            'src'         => ''
          )
        )
      ), 
	  
	   
	  

	  
 	   array(
        'id'          => 'contact_section_tab',
        'label'       => esc_html__( 'Contact', 'benten' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'contact_block',
        'label'       => esc_html__( 'You can create contact post in contact post.', 'benten' ),
        'desc'        => esc_html__( 'For creating contact post or inserting contact form 7 shortcode, go to left menu Contact Posts -> Add New Contact Post', 'benten' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'contact_small_title',
        'label'       => esc_html__( 'Contact Small Title', 'benten' ),
        'desc'        => esc_html__( 'Insert your small title for contact section here.', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'contact_big_title',
        'label'       => esc_html__( 'Contact Big Title', 'benten' ),
        'desc'        => esc_html__( 'Insert your big title for contact section here. eg. The Contact', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	
	array(
        'id'          => 'contact_icon',
        'label'       => esc_html__( 'Contact Icon', 'benten' ),
        'desc'        => esc_html__( 'Input your contact icon here. <br> You can check <a target="_blank" href="http://fontawesome.io/icons/">Here</a> for icon list. eg. fa-snowflake-o', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

      
	  array(
        'id'          => 'sub_address',
        'label'       => esc_html__( 'Insert Top/Small Text for Address', 'benten' ),
        'desc'        => esc_html__( 'Insert top/small text for address here. The default text is Come visit us', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  array(
        'id'          => 'tx_address',
        'label'       => esc_html__( 'Insert Text for Address', 'benten' ),
        'desc'        => esc_html__( 'Insert text for address here. The default text is The Address', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  array(
        'id'          => 'map_address',
        'label'       => esc_html__( 'Address', 'benten' ),
        'desc'        => esc_html__( 'Insert your address here. <br/>Leave it blank if you don\'t need it', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  array(
        'id'          => 'sub_phone',
        'label'       => esc_html__( 'Insert Top/Small Text for Phone', 'benten' ),
        'desc'        => esc_html__( 'Insert top/small text for phone here. The default text is Call us anytime', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'tx_phone',
        'label'       => esc_html__( 'Insert Text for Phone', 'benten' ),
        'desc'        => esc_html__( 'Insert text for phone here. The default text is The Phone', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'map_phone',
        'label'       => esc_html__( 'Phone', 'benten' ),
        'desc'        => esc_html__( 'Insert your phone here. <br/>Leave it blank if you don\'t need it', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'sub_email',
        'label'       => esc_html__( 'Insert Top/Small Text for Email', 'benten' ),
        'desc'        => esc_html__( 'Insert top/small text for email here. The default text is Send us today', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'tx_email',
        'label'       => esc_html__( 'Insert Text for Email', 'benten' ),
        'desc'        => esc_html__( 'Insert text for email here. The default text is The Email', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  array(
        'id'          => 'map_email',
        'label'       => esc_html__( 'Email', 'benten' ),
        'desc'        => esc_html__( 'Insert your email here. <br/>Leave it blank if you don\'t need it', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'sections_setting',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  


      
	  array(
        'id'          => 'parallax_one',
        'label'       => esc_html__('Parallax One/Services Setting', 'benten' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'parallax_section_big_background_image',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'parallax_image_one',
        'label'       => esc_html__('Parallax Image', 'benten' ),
        'desc'        => esc_html__('Upload your background image for parallax one/services section here.', 'benten' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'parallax_section_big_background_image',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'para_1_block',
        'label'       => esc_html__('You can create services list in services post', 'benten' ),
        'desc'        => esc_html__('For creating client list, go to left menu Services Posts ->Add New Services Posts', 'benten' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'parallax_section_big_background_image',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
      
      array(
        'id'          => 'parallax_two',
        'label'       => esc_html__('Parallax Two/Client List Setting', 'benten' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'parallax_section_big_background_image',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  array(
        'id'          => 'para2_block',
        'label'       => esc_html__('You can create client list in Section Settings (theme options)', 'benten' ),
        'desc'        => esc_html__('For creating client list, go to left menu Theme Options ->Section Settings ->Client List', 'benten' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'parallax_section_big_background_image',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'parallax_image_two',
        'label'       => esc_html__('Parallax Image', 'benten' ),
        'desc'        => esc_html__('Upload your background image for parallax two/client list here.', 'benten' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'parallax_section_big_background_image',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  
	  
	  
	  
	  array(
        'id'          => 'text_block_yt_section_rec',
        'label'       => esc_html__('THE SETTING ONLY FOR YOUTUBE VIDEO BACKGROUND IN HOMEPAGE YOUTUBE TEMPLATE', 'benten' ),
        'desc'        => esc_html__('You set your video here. This is only affect on homepage with <strong> Homepage Youtube</strong>', 'benten' ),
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'yt_bg_setting_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'yt_id',
        'label'       => esc_html__('Youtube Id', 'benten' ),
        'desc'        => esc_html__('Input your youtube ID here. <br /><strong>Remember only input the ID!</strong>. eg. c9MnSeYYtYY', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'yt_bg_setting_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	        array(
        'id'          => 'yt_qt',
        'label'       => esc_html__('Youtube Video Quality', 'benten' ),
        'desc'        => esc_html__('Insert your youtube video quality here. <br>You can input <b>small</b>, <b>medium</b>, <b>large</b>, <b>hd720</b>, <b>hd1080</b>, <b>highres</b>. 
		<br> Default value is large', 'benten' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'yt_bg_setting_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'yt_mute',
        'label'       => esc_html__('Youtube Video Mute', 'benten' ),
        'desc'        => esc_html__('You can turn on/off youtube video audio (mute)', 'benten' ),
        'std'         => '',
        'type'        => 'on-off',
        'section'     => 'yt_bg_setting_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
    )
  );
  
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( ot_settings_id() . '_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( ot_settings_id(), $custom_settings ); 
  }
  
  /* Lets OptionTree know the UI Builder is being overridden */
  global $ot_has_custom_theme_options;
  $ot_has_custom_theme_options = true;
  
}